{% extends "admin/change_form.html" %}


{% block object-tools %}
    {% if change %}
        {% if not is_popup %}
            <ul class="object-tools">
                <li><a href="history/" class="historylink">History</a></li>
                {% if has_absolute_url %}
                    <li><a href="{{original.get_absolute_url}}?preview=1" class="viewsitelink">View on site</a></li>
                {% endif%}
            </ul>
        {% endif %}
    {% endif %}
{% endblock %}